@@ -49,7 +49,7 @@ product_directories = [
     'macos1015',
     'ocp4',
     'rhcos4',
-    'ol7', 'ol8',
+    'ol7', 'ol8', 'ol9',
     'opensuse',
     'rhel7', 'rhel8', 'rhel9',
     'rhosp10', 'rhosp13',
@@ -210,6 +210,7 @@ FULL_NAME_TO_PRODUCT_MAPPING = {
     "Red Hat Enterprise Linux CoreOS 4": "rhcos4",
     "Oracle Linux 7": "ol7",
     "Oracle Linux 8": "ol8",
+    "Oracle Linux 9": "ol9",
     "openSUSE": "opensuse",
     "Red Hat Enterprise Linux 7": "rhel7",
     "Red Hat Enterprise Linux 8": "rhel8",
@@ -271,7 +272,7 @@ MULTI_PLATFORM_MAPPING = {
     "multi_platform_eks": ["eks"],
     "multi_platform_fedora": ["fedora"],
     "multi_platform_opensuse": ["opensuse"],
-    "multi_platform_ol": ["ol7", "ol8"],
+    "multi_platform_ol": ["ol7", "ol8", "ol9"],
     "multi_platform_ocp": ["ocp4"],
     "multi_platform_rhcos": ["rhcos4"],
     "multi_platform_rhel": ["rhel7", "rhel8", "rhel9"],
@@ -423,6 +424,8 @@ XCCDF_PLATFORM_TO_PACKAGE = {
   "non-uefi": None,
   "not_s390x_arch": None,
   "s390x_arch": None,
+  "ovirt": None,
+  "no_ovirt": None,
 }
 
 # _version_name_map = {
